==> UndernetCS-0.8.3.tar.gz: UndernetCS-0.8.3/src/UndernetCS-Conf.tcl <==
###############################################################################
#                 Undernet Channel Service Management Script                  #
###############################################################################
# $Id: UndernetCS-Conf.tcl,v 1.4 2001/08/09 12:59:40 Ze Exp $
###############################################################################
# Copyright (c) 2001 RICHARD Yann alias Ze <Ze@administrateur.net>            #
###############################################################################

###############################################################################
# This program is distributed under the GNU General Public Licence            #
# See the LICENCE file for more information.                                  #
###############################################################################

# Set this to the location where you want data of UndernetCS will
# be saved.
# ie: if your data file is in /home/yourShell/eggdrop/conf/mydatafile
# set this to conf/mydatafile
# !!! This is different than UndernetCS-Conf.tcl file !!!!
set UndernetCS_ConfFile {conf/UndernetCS.conf}

# Set this to the directory who you want to store the backup
# Last '/' isn't important...
set UndernetCS_BackupDir "conf"

# Set this to the extention you want for backup of your config file.
# There is no backup at the momment ;)
set UndernetCS_BackupExtention ".bak"

# Set this to the Undernet's username of your eggdrop.
# You can set theirs two var now or in the party line ...
# See .CS in party line...
set UndernetCS_X(USERID) {Antigone}

# Password must be set via party line with '.cs set pass <password>' command

# Loading inidb.tcl from UndernetCS script dir ? [0/1]
set UndernetCS_Must_Load_inidb 1

# X's mask (Theoricaly you mustn't change this ...), but if you used the 
# CMaster program who are distributed on sourceforge.net ...
# in lower case ...
set UndernetCS_XMask {x!cservice@undernet.org}
set UndernetCS_XAdrSend {x@channels.undernet.org}
set UndernetCS_Nick {x}

### EOF ###

==> UndernetCS-0.8.5.tar.gz: UndernetCS-0.8/src/UndernetCS-Conf.tcl <==
###############################################################################
#                 Undernet Channel Service Management Script                  #
###############################################################################
# $Id: UndernetCS-Conf.tcl,v 1.4 2003/05/19 18:18:16 Ze Exp $
###############################################################################
# (c) 2001 RICHARD Yann alias Ze <mgm@ifrance.com>                            #
###############################################################################

###############################################################################
# This program is distributed under the GNU General Public Licence            #
# See the LICENCE file for more information.                                  #
###############################################################################

# Set this to the location where you want data of UndernetCS will
# be saved.
# ie: if your data file is in /home/yourShell/eggdrop/conf/mydatafile
# set this to conf/mydatafile
# !!! This is different than UndernetCS-Conf.tcl file !!!!
set UndernetCS_ConfFile {conf/UndernetCS.conf}

# Set this to the directory who you want to store the backup
# Last '/' isn't important...
set UndernetCS_BackupDir "conf"

# Set this to the extention you want for backup of your config file.
# There is no backup at the momment ;)
set UndernetCS_BackupExtention ".bak"

# Set this to the Undernet's username of your eggdrop.
# You can set theirs two var now or in the party line ...
# See .CS in party line...
set UndernetCS_X(USERID) {Your_Undernet_Username}

# Password must be set via party line with '.cs set pass <password>' command

# Loading inidb.tcl from UndernetCS script dir ? [0/1]
set UndernetCS_Must_Load_inidb 1

# X's mask (Theoricaly you mustn't change this ...), but if you used the 
# CMaster program who are distributed on sourceforge.net ...
# in lower case ...
set UndernetCS_XMask {x!cservice@undernet.org}
set UndernetCS_XAdrSend {x@channels.undernet.org}
set UndernetCS_Nick {x}

# If you want your eggdrop set usermode +x when connect into IRC server 
# set this to 1, else set this to 0.
set UndernetCS_X(MODEX) 0

# News Checker config
# [0/1] Do you want UndernetCS verify every day at 4h if there is a new release
# of the script ? (Only permanent owner will be notified).
set UndernetCS_UseNewsChecker 0

### EOF ###
